*****
tests
*****

The riroriro/tests directory contains unit tests for the main Riroriro modules, utilising pytest. The tests can be performed with Tox by using the standard command ``tox -e test`` in the install directory.
